@@ -20,7 +20,6 @@ from runlocal_hub.models import (
 from runlocal_hub.models.job import JobResult
 from runlocal_hub.models.model import UploadDbItem
 from runlocal_hub.utils.display import display_incomplete_panel
-from runlocal_hub.utils.json import convert_to_json_friendly
 
 from .devices import DeviceFilters, DeviceSelector
 from .exceptions import ConfigurationError, RunLocalError, UploadError, ValidationError
@@ -28,7 +27,6 @@ from .http import HTTPClient
 from .jobs import JobPoller
 from .models import (
     BenchmarkData,
-    BenchmarkDataFloat,
     BenchmarkResponse,
     BenchmarkResult,
     Device,
@@ -52,6 +50,7 @@ class RunLocalClient:
 
     def __init__(
         self,
+        api_key: Optional[str] = None,
         local_server: bool = False,
         verbosity: int = 2,
     ):
@@ -59,11 +58,14 @@ class RunLocalClient:
         Initialize the RunLocal client.
 
         Args:
+            api_key: Manually specify the RunLocal API key to use
             debug: Enable debug logging (deprecated, use verbosity=3 instead)
             local_server: Use local server instead of production
             verbosity: Control output verbosity (0=silent, 1=minimal, 2=normal 3=verbose, 4=debug). Uses instance default if not specified
         """
-        api_key = os.environ.get(self.ENV_VAR_NAME)
+        if api_key is None:
+            api_key = os.environ.get(self.ENV_VAR_NAME)
+
         if not api_key:
             raise ConfigurationError(
                 f"API key not found. Please set the {self.ENV_VAR_NAME} environment variable.",
@@ -192,16 +194,13 @@ class RunLocalClient:
             if benchmark_item.Status != BenchmarkStatus.Complete:
                 continue
 
-            result = convert_to_json_friendly(benchmark_item)
+            result = benchmark_item.model_dump()
             device = result.get("DeviceInfo", {})
 
             # Convert benchmark data to float format
             benchmark_data = []
             for bd in result.get("BenchmarkData", []):
-                original_bd = BenchmarkData(**bd)
-                benchmark_data.append(
-                    BenchmarkDataFloat.from_benchmark_data(original_bd)
-                )
+                benchmark_data.append(BenchmarkData(**bd))
             benchmark_result = BenchmarkResult(
                 device=device,
                 benchmark_data=benchmark_data,
@@ -783,10 +782,7 @@ class RunLocalClient:
                 # Convert benchmark data to float format
                 benchmark_data = []
                 for bd in result.data.get("BenchmarkData", []):
-                    original_bd = BenchmarkData(**bd)
-                    benchmark_data.append(
-                        BenchmarkDataFloat.from_benchmark_data(original_bd)
-                    )
+                    benchmark_data.append(BenchmarkData(**bd))
 
                 output_tensors = None
                 if not skip_output_download:
@@ -816,8 +812,9 @@ class RunLocalClient:
             else:
                 # Log the error but don't include failed results
                 if self.verbosity >= 2:
+                    device_name = result.device.Name if result.device else ""
                     print(
-                        f"Warning: Benchmark failed for device {result.device_name}: {result.error}"
+                        f"Warning: Benchmark failed for device {device_name}: {result.error}"
                     )
 
         return processed_results
@@ -880,14 +877,16 @@ class RunLocalClient:
                     processed_results.append(prediction_result)
                 else:
                     if self.verbosity >= 2:
+                        device_name = result.device.Name if result.device else ""
                         print(
-                            f"Warning: Prediction completed but no output tensors found for device {result.device_name}"
+                            f"Warning: Prediction completed but no output tensors found for device {device_name}"
                         )
             else:
                 # Log the error but don't include failed results
                 if self.verbosity >= 2:
+                    device_name = result.device.Name if result.device else ""
                     print(
-                        f"Warning: Prediction failed for device {result.device_name}: {result.error}"
+                        f"Warning: Prediction failed for device {device_name}: {result.error}"
                     )
 
         return processed_results
