@@ -1,5 +1,4 @@
 from .console import JobStatusDisplay, StatusColors
-from .json import RunLocalJSONEncoder, convert_to_json_friendly
 from .display import (
     display_benchmark_results,
     display_failed_benchmarks,
@@ -8,8 +7,6 @@ from .display import (
 )
 
 __all__ = [
-    "RunLocalJSONEncoder",
-    "convert_to_json_friendly",
     "JobStatusDisplay",
     "StatusColors",
     "display_benchmark_results",
